Struct ZwlrOutputConfigurationV1
pub struct ZwlrOutputConfigurationV1 { /* private fields */ }wayland and Linux only.Expand description
output configuration
This object is used by the client to describe a full output configuration.
First, the client needs to setup the output configuration. Each head can be either enabled (and configured) or disabled. It is a protocol error to send two enable_head or disable_head requests with the same head. It is a protocol error to omit a head in a configuration.
Then, the client can apply or test the configuration. The compositor will then reply with a succeeded, failed or cancelled event. Finally the client should destroy the configuration object.
See also the Event enum for this interface.
Implementations
impl ZwlrOutputConfigurationV1
impl ZwlrOutputConfigurationV1
pub fn enable_head<U, D>(
&self,
head: &ZwlrOutputHeadV1,
qh: &QueueHandle<D>,
udata: U,
) -> ZwlrOutputConfigurationHeadV1
pub fn enable_head<U, D>( &self, head: &ZwlrOutputHeadV1, qh: &QueueHandle<D>, udata: U, ) -> ZwlrOutputConfigurationHeadV1
enable and configure a head
Enable a head. This request creates a head configuration object that can be used to change the head’s properties.
pub fn disable_head(&self, head: &ZwlrOutputHeadV1)
pub fn disable_head(&self, head: &ZwlrOutputHeadV1)
disable a head
Disable a head.
pub fn apply(&self)
pub fn apply(&self)
apply the configuration
Apply the new output configuration.
In case the configuration is successfully applied, there is no guarantee that the new output state matches completely the requested configuration. For instance, a compositor might round the scale if it doesn’t support fractional scaling.
After this request has been sent, the compositor must respond with an succeeded, failed or cancelled event. Sending a request that isn’t the destructor is a protocol error.
pub fn test(&self)
pub fn test(&self)
test the configuration
Test the new output configuration. The configuration won’t be applied, but will only be validated.
Even if the compositor succeeds to test a configuration, applying it may fail.
After this request has been sent, the compositor must respond with an succeeded, failed or cancelled event. Sending a request that isn’t the destructor is a protocol error.
pub fn destroy(&self)
pub fn destroy(&self)
destroy the output configuration
Using this request a client can tell the compositor that it is not going to use the configuration object anymore. Any changes to the outputs that have not been applied will be discarded.
This request also destroys wlr_output_configuration_head objects created via this object.